@@ -20,12 +20,6 @@ pub trait CaptureStream<'a>: Stream {
     /// Remove a buffer from the drivers' outgoing queue
     fn dequeue(&mut self) -> io::Result<usize>;
 
-    /// Get the buffer at the specified index
-    fn get(&self, index: usize) -> Option<&Self::Item>;
-
-    /// Get the metadata at the specified index
-    fn get_meta(&self, index: usize) -> Option<&Metadata>;
-
     /// Fetch a new frame by first queueing and then dequeueing.
     /// First time initialization is performed if necessary.
     fn next(&'a mut self) -> io::Result<(&Self::Item, &Metadata)>;
@@ -38,12 +32,6 @@ pub trait OutputStream<'a>: Stream {
     /// Remove a buffer from the drivers' outgoing queue
     fn dequeue(&mut self) -> io::Result<usize>;
 
-    /// Get the buffer at the specified index
-    fn get(&mut self, index: usize) -> Option<&mut Self::Item>;
-
-    /// Get the metadata at the specified index
-    fn get_meta(&mut self, index: usize) -> Option<&mut Metadata>;
-
     /// Dump a new frame by first queueing and then dequeueing.
     /// First time initialization is performed if necessary.
     fn next(&'a mut self) -> io::Result<(&mut Self::Item, &mut Metadata)>;
