@@ -37,22 +37,19 @@ impl fmt::Display for Parameters {
 
 impl From<v4l2_outputparm> for Parameters {
     fn from(params: v4l2_outputparm) -> Self {
-        Parameters {
+        Self {
             capabilities: Capabilities::from(params.capability),
             interval: Fraction::from(params.timeperframe),
         }
     }
 }
 
-impl Into<v4l2_outputparm> for Parameters {
-    fn into(self: Parameters) -> v4l2_outputparm {
-        let mut params: v4l2_outputparm;
-        unsafe {
-            params = mem::zeroed();
+impl From<Parameters> for v4l2_outputparm {
+    fn from(parameters: Parameters) -> Self {
+        Self {
+            capability: parameters.capabilities.into(),
+            timeperframe: parameters.interval.into(),
+            ..unsafe { mem::zeroed() }
         }
-
-        params.capability = self.capabilities.into();
-        params.timeperframe = self.interval.into();
-        params
     }
 }
